==============================================
 RTIntegration - Python interface to Request Tracker API REST 2.0
==============================================

Python implementation of REST API described here: https://rt-wiki.bestpractical.com/wiki/REST

**Note:** Please note that starting with the major release of v0.0.1, this library requires a Python version >= 3.5.

REQUIREMENTS
============

This module uses following Python modules:

- requests (http://docs.python-requests.org/)

INSTALLATION
============

Install the package using::

  pip install rti


LICENCE
=======

This module is distributed under the terms of ... Copy of the GNU
General Public License is distributed along with this module.

USAGE
=====

An example is worth a thousand words::

    >>> import rti
   

Get the last important updates from a specific queue that have been updated recently::

    >>> import rti

		

OFFICIAL SITE
=============

Project site and issue tracking:
    https://github.com/infopontes/rti

Git repository:
    git://github.com/infopontes/rti